==> driza-0.5.tar.gz: driza-0.5.0/Driza/dialogs/doperaciones.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from Driza.ui.dialogos.operaciones import DialogoOperaciones

class DOperaciones(DialogoOperaciones):
	"""Dialogo  de operaciones"""

	def __init__(self,parent,gestoroperaciones,vsalida):
		DialogoOperaciones.__init__(self,parent,"Dialogo casos",0,0)
		self.__gestoroperaciones=gestoroperaciones
		self.__initwidgets()
		self.__conexiones()
		self.__vsalida=vsalida
		self.__noimplementado=QLabel(None,"No implementado")
		self.__noimplementado.setText("No implementado")
		self.widgetStack1.addWidget(self.__noimplementado)
		self.listView2.addColumn("Operaciones")
	
	def show(self,operacion=None):
		self.__showarbol()
#		self.__showwidget() #Mas que para show esta funcion debe ser llamada para __conexiones
		if operacion:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[operacion].widget)
			self.listView2.ensureItemVisible(self.listView2.findItem(operacion,0))
			self.listView2.setCurrentItem(self.listView2.findItem(operacion,0))
		DialogoOperaciones.show(self)

	def accept(self):
		"""Acepta el dialogo. Coge la operacion con la que esta trabajando el usuario e inicia el procedimiento de calculo"""
	#	try:
		resultado=self.__gestoroperaciones[self.listView2.currentItem().text(0).latin1()].procedimiento()
		self.__vsalida.app_obj(resultado) #Añadir a la salida el resultado
		self.__vsalida.show()
	#	except:
	#		pass #TODO: Aqui debe controlarse si no hay seleccion , si ha habido algun problema con R


	def __initwidgets(self):
		"""Añade los widgets en el widgetstack"""
		for operacion in self.__gestoroperaciones.values():
			self.widgetStack1.addWidget(operacion.widget)


	def __conexiones(self):
		self.connect(self.listView2,SIGNAL("selectionChanged ()"),self.__showwidget)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.accept)

	def __showarbol(self):
		"""Muestra el arbol segun el contenido de gestoroperaciones"""
		self.listView2.clear()
		self.__textocalculo=QListViewItem(self.listView2,"Calculo");
		QListViewItem(self.__textocalculo,"descriptivo")
		QListViewItem(self.__textocalculo,"regresion")
		QListViewItem(self.__textocalculo,"ks")
		QListViewItem(self.__textocalculo,"jicuadrado")
		self.__textocalculo=QListViewItem(self.listView2,"Graficos");
		QListViewItem(self.__textocalculo,"histograma")

	def __showwidget(self):
		"""Muestra el widget asociado a la seleccion actual"""
		nombre=self.listView2.currentItem().text(0).latin1()
		try:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[nombre].widget)
		except KeyError:
			self.widgetStack1.raiseWidget(self.__noimplementado)

==> driza-0.5.1.tar.gz: driza-0.5.1/Driza/dialogs/doperaciones.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from Driza.ui.dialogos.operaciones import DialogoOperaciones

class DOperaciones(DialogoOperaciones):
	"""Dialogo  de operaciones"""

	def __init__(self,parent,gestoroperaciones,vsalida):
		DialogoOperaciones.__init__(self,parent,"Dialogo casos",0,0)
		self.__gestoroperaciones=gestoroperaciones
		self.__initwidgets()
		self.__conexiones()
		self.__vsalida=vsalida
		self.__noimplementado=QLabel(None,"No implementado")
		self.__noimplementado.setText("No implementado")
		self.widgetStack1.addWidget(self.__noimplementado)
		self.listView2.addColumn("Operaciones")
	
	def show(self,operacion=None):
		self.__showarbol()
#		self.__showwidget() #Mas que para show esta funcion debe ser llamada para __conexiones
		if operacion:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[operacion].widget)
			self.listView2.ensureItemVisible(self.listView2.findItem(operacion,0))
			self.listView2.setCurrentItem(self.listView2.findItem(operacion,0))
		DialogoOperaciones.show(self)

	def accept(self):
		"""Acepta el dialogo. Coge la operacion con la que esta trabajando el usuario e inicia el procedimiento de calculo"""
	#	try:
		resultado=self.__gestoroperaciones[self.listView2.currentItem().text(0).latin1()].procedimiento()
		self.__vsalida.app_obj(resultado) #Añadir a la salida el resultado
		self.__vsalida.show()
	#	except:
	#		pass #TODO: Aqui debe controlarse si no hay seleccion , si ha habido algun problema con R


	def __initwidgets(self):
		"""Añade los widgets en el widgetstack"""
		for operacion in self.__gestoroperaciones.values():
			self.widgetStack1.addWidget(operacion.widget)


	def __conexiones(self):
		self.connect(self.listView2,SIGNAL("selectionChanged ()"),self.__showwidget)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.accept)

	def __showarbol(self):
		"""Muestra el arbol segun el contenido de gestoroperaciones"""
		self.listView2.clear()
		self.__textocalculo=QListViewItem(self.listView2,"Calculo")
		QListViewItem(self.__textocalculo,"descriptivo")
		QListViewItem(self.__textocalculo,"regresion")
		QListViewItem(self.__textocalculo,"ks")
		QListViewItem(self.__textocalculo,"jicuadrado")
		self.__textocalculo=QListViewItem(self.listView2,"Graficos")
		QListViewItem(self.__textocalculo,"histograma")
		distribuciones=QListViewItem(self.listView2,"Distribuciones")
		QListViewItem(distribuciones,"dnormal")

	def __showwidget(self):
		"""Muestra el widget asociado a la seleccion actual"""
		nombre=self.listView2.currentItem().text(0).latin1()
		try:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[nombre].widget)
		except KeyError:
			self.widgetStack1.raiseWidget(self.__noimplementado)
